Integration tests for Savanna project
=====================================

How to run
----------

Create config file for integration tests - `/savanna/tests/integration/configs/config.py`.
You can take a look at the sample config file - `/savanna/tests/integration/configs/config.py.sample`.
All values used in `/savanna/tests/integration/configs/parameters.py`
file are defaults, so, if their are applicable for your environment than you
can skip config file creation.

To run integration tests you should use the corresponding tox env: `tox -e integration`.

Contents
--------

TBD
